# Curious

Curious is a Python 3.6+ wrapper for the Discord API, using
[curio](https://github.com/dabeaz/curio).

## Installation

Curious is available on PyPI under `discord-curious`:

```bash
$ pip install -U discord-curious
```

Or for the latest development version:

```bash
$ pip install -U git+https://github.com/SunDwarf/curious.git#egg=curious
```

## Documentation

See the documentation at https://curious.readthedocs.io/en/latest/.

